/*
 * Copyright (c) 2001 University of Bologna
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library Public License for more details.
 *
 * You should have received a copy of the GNU Library Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill;

/**
 *  Basic implementation of the AntDescriptor interface. As suggested by
 *  objects, objects contain information about the agent executed
 *  by the current thread.
 *
 *  @author Alberto Montresor
 *  @version $REVISION$
 */
public class AntDescriptor
{
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** AnthillId of the sender of this agent */
  private AnthillId sender;
  
  /** Ant associated to this data structure */
  private Ant agent;
  
  /** Time-to-live */
  private int ttl;
  
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *
   */
  public AntDescriptor(AnthillId sender, Ant agent, int ttl)
  {
    this.sender = sender;
    this.agent = agent;
    this.ttl = ttl;
  }
  
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Return the agent executed by the current thread.
   */
  public Ant getAnt()
  {
    return agent;
  }
  
  /**
   *  Return the original sender of this agent.
   */
  public AnthillId getSender()
  {
    return sender;
  }

  /**
   *  Return the time-to-live of this agent.
   */
  public int getTTL()
  {
    return ttl;
  }

} // END AntDescriptor


