/*
 * Copyright (c) 2001 University of Bologna
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library Public License for more details.
 *
 * You should have received a copy of the GNU Library Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill;

import java.rmi.*;

/**
 *  This interface contains method deliver(), which should be
 *  implemented by a anthill in order to receive an agent
 *  from other anthills. The interface is implemented as a remote
 *  interface (it extends Remote and method deliver() throws
 *  RemoteException); however, implementations of this class are
 *  not required to be based on RMI. 
 *
 *  @author Alberto Montresor
 *  @version $REVISION$
 */
public interface AntListener
extends Remote
{

  /**
   *  This method is invoked to notify the implementation object
   *  that an agent coming from the specified anthill has been
   *  received.
   *
   *  @param sender the identifier of the anthill from which this agent 
   *    has been received
   *  @param desc the descriptor of the received agent
   *  @exception RemoteException added to the throw clause to respect
   *    the conventions for remote interfaces.
   */
  public void deliver(AntDescriptor desc)
    throws RemoteException;

  
} // END AntListener
