/*
 * Copyright (c) 2001 University of Bologna
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library Public License for more details.
 *
 * You should have received a copy of the GNU Library Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill;

import anthill.util.*;

/**
 *  The aim of a <CODE>Manager</CODE> is to control the execution of
 *  the ants receveid by other anthills or generated locally.
 *  The <CODE>Manager</CODE> interface enable the insertion of new ants
 *  in the manager, and to force the execution of the ant code.
 *  Classes implementing this interface may provide different
 *  semantics for execution; for example, classes implementing
 *  <CODE>Manager</CODE> used during the off-line simulation should be
 *  single-threaded, while "real" implementation will be
 *  probably multi-threaded.
 *
 *  @author Alberto Montresor
 *  @version $REVISION$
 */
public interface Manager
extends Clearable
{
  
  /**
   *  Add an ant to the queue of ants to be executed.
   *  The ant is added by passing an <CODE>AntView</CODE> object,
   *  which encapsulate the ant and the environment
   *  it can view.
   *
   *  @param view the ant to be added, together with
   *    its environment
   */
  public void add(AntView view);
  
  
  /**
   *  Force the execution of an ant stored in this
   *  <CODE>Manager</CODE>. 
   */
  public void execute();
  
} // END Manager
