/*
 * Copyright (c) 2001 University of Bologna
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library Public License for more details.
 *
 * You should have received a copy of the GNU Library Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package anthill.nestor;

import anthill.*;
import java.util.*;
import java.io.*;

/**
 *
 *  @author Alberto Montresor
 *  @version $REVISION$
 */
public class RandomResource
implements Resource
{

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Static field
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** Random generator */
  static private Random random = new Random();
  
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** String name of the resource, randomly generated */
  private String name;
  

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructor
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Construct a resource with a random name
   */
  public RandomResource()
  {
    long value = random.nextLong();
    name = Long.toString(value);
  }
  

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Returns the string identifier of the object.
   */
  public String getName()
  {
    return name;
  }
  
  
  /**
   *  Returns the value associated to the specified attribute
   *  name, or <CODE>null</CODE> if there is no attribute with that name.
   *  <p>
   *  Implementation note: in this simple implementation, the
   *  attribute feature is not present; value <CODE>null</CODE>
   *  is returned.
   *
   *  @param name the name of the attribute
   */
  public String getAttribute(String name)
  {
    return null;
  }

  
  /**
   *  Return an input stream to download the contents of the
   *  resource. Depending on the implementation, the contents
   *  may be read from the local storage, if the resource has
   *  been copied locally; or downloaded remotely, otherwise.
   *
   *  @return an input stream to read the contents of a resource;
   */
  public InputStream getInputStream()
  {
    throw new UnsupportedOperationException();
  }

  
  /**
   *  Return the lenght of the content of the resource, if
   *  available; otherwise, it returns -1.
   *  <p>
   *  Implementation note: in this simple implementation, the
   *  content length feature is not present; value <CODE>-1</CODE>
   *  is returned.
   */
  public long getContentLength()
  {
    return -1;
  }


  /**
   *  Return a string representing this resource
   */
  public String toString()
  {
    StringBuffer buf = new StringBuffer();
    buf.append("[");
    buf.append(this.getClass().getName());
    buf.append(": ");
    buf.append(name);
    buf.append("]");
    return buf.toString();
  }
  
  /**
   *  Indicates whether some other object is "equal to" this one
   */
  public boolean equals(Object obj)
  {
    try {
      RandomResource resource = (RandomResource) obj;
      return resource.name.equals(this.name);
    } catch (Exception e) {
      return false;
    }
  }

  
  
} // END RandomResource

