/*
 * Copyright (c) 2000-2001 University of Bologna
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Library Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library Public License for more details.
 *
 * You should have received a copy of the GNU Library Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package test;

import anthill.*;
import anthill.gf.*;
import anthill.util.*;

/**
 *  Main simulator class.
 *
 *  @author Alberto Montresor
 */
public class Simulator
{

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constants
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** Number of scenarios on which testing a population */
  private static final int NUMSCENARIOS = 10;

  /** Default percentage of population carried forward unchanged from each generation */
  private static final double ELITERATE = 0.2;
 
  /** Default percentage deemed unfit for reproduction */
  private static final double CULLRATE  = 0.8;

  /** Mutation rate */ 
  private static final double MUTRATE   = 0.02;

  /** Number of chromosoms (dna sequences) constituting the population */
  private static final int NUMCHROMS    = 50;
  
  /** Number of genes (bit sequences) constituting a chromosome */
  private static final int NUMGENES     = 16*5; 

  /** Default size of a single gene (bit number) */
  private static final int SIZEGENES    = 1;
  
  /** Default number of generations */
  private static final int GENERATIONS  = 50;
  
  /** Iterations */
  private static final int ITERATIONS = 1000;
  
  /** Iterations */
  private static final int NRESOURCES = 100;

  /** Default size of networks */
  private static final int SIZE  = 100;
  
  /** Default size of networks */
  private static final int TTL  = 10;

  /** Default degree of networks */
  private static final int DEGREE  = 5;

  /** Default capacity */
  private static final int CAPACITY = 30;
  
  /** Map size */
  private static final int MAPSIZE = 65;
  
  /** Init */
  private static final float INIT = 0.05f;
  
  
  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Main method
  ////////////////////////////////////////////////////////////////////////////////////////////

  

  /**
   * Short concise description.
   * @param args description.
   * @exception Exception description.
   */
  public static void main(String[] args)
    throws Exception
  {
    // Create the opportune objects
    // FIXME Jessica: qui dovresti anche creare opportune "factory" per le sottoparti
    //  che costituiscono uno scenario, tipo grafo, risorse e richieste
    // FIXME Alberto: Sostituire questa creazione statica con creazione dinamica,
    //  magari basata su file di configurazione in XML
    
    AntViewFactory marketf = 
      new anthill.nestor.NestorAntViewFactory();
    
    StorageFactory storagef = 
      new anthill.nestor.LocalStorageFactory(CAPACITY);
    
    GateFactory gatef = 
      new anthill.nestor.LocalGateFactory();

    ManagerFactory managerf = 
      new anthill.nestor.SimulationManagerFactory();

    QuerySetFactory querysetf = 
      new anthill.nestor.LocalQuerySetFactory();
    
    anthill.yessensis.PheromoneFactory pheromonef =
      new anthill.yessensis.PheromoneFactory(MAPSIZE, INIT);
    
    AntFactory antf = 
      new anthill.yessensis.YessensisFactory(pheromonef);

    AnthillFactory anthillf = 
      new anthill.nestor.NestorAnthillFactory(storagef, gatef, managerf, querysetf,
      antf, marketf, TTL);

    PeernetFactory peernetf = 
      new anthill.genie.PeernetFactoryImpl(anthillf, SIZE, DEGREE);
      
    anthill.gf.ResourceFactory resourcef =
      new anthill.nestor.RandomResourceFactory();
    
    ScenarioFactory scenariof = 
      new anthill.genie.ScenarioFactoryImpl(peernetf, resourcef, ITERATIONS, NRESOURCES);
      
    ExperimentFactory experimentf = 
      new anthill.genie.ExperimentFactoryImpl(scenariof, NUMSCENARIOS);
      
    GeneticFramework gf = 
      new anthill.genie.GeneticFrameworkImpl(NUMCHROMS, NUMGENES, SIZEGENES, MUTRATE,
      ELITERATE, CULLRATE, GENERATIONS, experimentf);
      
    // Print the configuration parameter on the screen
    Log.println(gf);
    
    gf.evolve();
    
    // FIXME: decidere cosa fare qui, salvare il cromosoma cosi' ottenuto da qualche
    // parte?
  }

    
} // END Simulator


